@@ -5,12 +5,13 @@
 #' will be named "<columnname>.ff".
 #' A saved ffdf data.frame is a .rdata file and can be loaded with the \code{load} function
 #' Deprecated, the preferred method is \code{\link{save.ffdf}}
-#' @example ../examples/ffdfsave.R
+#' @rdname pkg-deprecated
 #' @export
 #' @param dat \code{ffdf} data.frame, to be saved
 #' @param filename path where .rdata file will be save and <filename>_ff directory will be created
 ffdfsave <- function(dat, filename){
-  
+   .Deprecated("Use save.ffdf")
+   
    datname <- deparse(substitute(dat))
    
    # create a sub directory with "<filename>_ff"
